@@ -14,8 +14,7 @@ class EntitiesBasicTC(MercurialServerTCMixin, CubicWebTC):
 
     def test_repotitle_constraint(self):
         with self.assertRaises(ValidationError) as wraperr:
-            self.create_local_mercurial_repo(self.basepath, u'default',
-                                             u'testrepo', u'test repo')
+            self.create_mercurial_repo(self.request(), u'test repo')
         wraperr.exception.translate(lambda x:x)
         self.assertEqual({'title-subject': u"u'test repo' doesn't match the '^\\\\w+$' regular expression"},
                          wraperr.exception.args[1])
@@ -28,7 +27,7 @@ class EntitiesBasicTC(MercurialServerTCMixin, CubicWebTC):
                 fobj.write('Hello World\n')
             commands.add(ui, repo, filename)
 
-        content = self._hgadmin_file_content('default', 'whatever.txt')
+        content = self._hgadmin_file_content('whatever.txt')
         self.assertEqual(content, 'Hello World\n')
 
 
