@@ -31,12 +31,12 @@ class HooksBasicTC(MercurialServerTCMixin, CubicWebTC):
 
     def _assert_end_of_prologue(self, access_key, perm):
         # Testing addition
-        pubkey = self._hgadmin_file_content('default', 'keys', self.server_config.keys_subdir,
+        pubkey = self._hgadmin_file_content('keys', self.server_config.keys_subdir,
                                             self.user().login, str(access_key.eid))
-        self.assertEqual(pubkey, 'admin private key')
+        self.assertEqual(pubkey, 'admin public key')
 
         # Check access.conf content
-        content = self._hgadmin_file_content('default', self.server_config.conf_filename)
+        content = self._hgadmin_file_content(self.server_config.conf_filename)
         self.assertEqual(content,
                          'write user=cw/%(login)s/%(key_eid)d repo=admin_repo\n'
                          % {'login': self.user().login,
@@ -62,11 +62,11 @@ class HooksBasicTC(MercurialServerTCMixin, CubicWebTC):
         self.commit()
 
         # Check access.conf content
-        content = self._hgadmin_file_content('default', self.server_config.conf_filename)
+        content = self._hgadmin_file_content(self.server_config.conf_filename)
         self.assertEqual(content, '\n')
 
         with self.assertRaises(IOError):
-            self._hgadmin_file_content('default', 'keys', self.server_config.keys_subdir,
+            self._hgadmin_file_content('keys', self.server_config.keys_subdir,
                                        self.user().login, str(access_key.eid))
 
     def test_msc_deletion_with_rollback_inside(self):
@@ -90,11 +90,11 @@ class HooksBasicTC(MercurialServerTCMixin, CubicWebTC):
         """ Test Adding, Updating and Deleting """
         access_key, perm = self._test_permission_prologue()
         # Updating
-        perm.set_attributes(permission_level=u"write")
+        perm.cw_set(permission_level=u"write")
         self.commit() # Triggers hooks
         # Testing update
         # Check access.conf content
-        content = self._hgadmin_file_content('default', self.server_config.conf_filename)
+        content = self._hgadmin_file_content(self.server_config.conf_filename)
         self.assertEqual(content,
                          'write user=cw/%(login)s/%(key_eid)d repo=admin_repo\n'
                          % {'login': self.user().login,
@@ -106,7 +106,7 @@ class HooksBasicTC(MercurialServerTCMixin, CubicWebTC):
         perm.cw_delete()
         self.commit() # Triggers hooks
         #Check access.conf content
-        content = self._hgadmin_file_content('default', self.server_config.conf_filename)
+        content = self._hgadmin_file_content(self.server_config.conf_filename)
         self.assertEqual(content, '\n')
 
 
@@ -115,10 +115,10 @@ class HooksBasicTC(MercurialServerTCMixin, CubicWebTC):
         access_key, perm = self._test_permission_prologue()
 
         # Updating
-        access_key.set_attributes(data=Binary('24'))
+        access_key.cw_set(data=Binary('24'))
         self.commit() # Triggers hooks
         # Testing update
-        pubkey = self._hgadmin_file_content('default', 'keys', 'cw',
+        pubkey = self._hgadmin_file_content('keys', 'cw',
                                             self.user().login, str(access_key.eid))
         self.assertEqual(pubkey, '24')
 
@@ -127,11 +127,11 @@ class HooksBasicTC(MercurialServerTCMixin, CubicWebTC):
         self.commit() # Triggers hooks
         # Testing deletion
         with self.assertRaises(IOError) as exc :
-            pubkey = self._hgadmin_file_content('default', 'keys', 'cw',
+            pubkey = self._hgadmin_file_content('keys', 'cw',
                                                 self.user().login, str(access_key.eid))
 
         # Check access.conf content
-        content = self._hgadmin_file_content('default', self.server_config.conf_filename)
+        content = self._hgadmin_file_content(self.server_config.conf_filename)
         self.assertEqual(content, '\n')
 
 
@@ -160,22 +160,20 @@ class HooksBasicTC(MercurialServerTCMixin, CubicWebTC):
 class SchemaPermTC(MercurialServerTCMixin, CubicWebTC):
 
     def test_ordinary_user_AUD(self):
-        toto = self.create_user(u'toto')
-        titi = self.create_user(u'titi')
+        toto = self.create_user(self.request(), u'toto')
+        titi = self.create_user(self.request(), u'titi')
         self.commit()
         with self.userlogin('toto') as cnx:
             # toto cannot create a mercurial server config
             req = cnx.request()
             with self.assertRaises(Unauthorized):
-                self.create_local_mercurial_server(self.basepath, 'for_toto')
+                self.create_mercurial_server(req, 'for_toto')
         with self.userlogin('toto') as cnx:
             # without a public key, toto cannot create a hosted repository
             req = cnx.request()
-            toto_repo = self.create_local_mercurial_repo(self.basepath,
-                                                         'default', 'toto_repo',
-                                                         u'Repo_for_user_toto')
+            toto_repo = self.create_mercurial_repo(req, 'toto_repo')
             with self.assertRaises(ValidationError) as wraperr:
-                toto_repo.set_relations(hosted_by=self.server_config)
+                toto_repo.cw_set(hosted_by=self.server_config)
             self.assertEqual({'hosted_by': 'To create a hosted repository, toto must have a public key'},
                              wraperr.exception.args[1])
         with self.userlogin('titi') as cnx:
@@ -184,9 +182,7 @@ class SchemaPermTC(MercurialServerTCMixin, CubicWebTC):
             pubkey = req.create_entity('SshPubKey', data=Binary('titi public key'),
                                        reverse_public_key=titi.eid)
             cnx.commit()
-            titi_repo = self.create_local_mercurial_repo(self.basepath,
-                                                         'default', 'titi_repo',
-                                                         u'Repo_for_user_titi')
+            titi_repo = self.create_mercurial_repo(req, 'titi_repo')
             cnx.commit()
         with self.userlogin('toto') as cnx:
             req = cnx.request()
@@ -194,10 +190,7 @@ class SchemaPermTC(MercurialServerTCMixin, CubicWebTC):
                                        reverse_public_key=toto.eid)
             cnx.commit()
             req = cnx.request()
-            toto_repo = self.create_local_mercurial_repo(self.basepath,
-                                                         'default', 'toto_repo',
-                                                         u'Repo_for_user_toto')
-            toto_repo.set_relations(hosted_by=self.server_config)
+            toto_repo = self.create_mercurial_repo(req, 'toto_repo', hosted_by=self.server_config)
             cnx.commit()
             req = cnx.request()
             with self.assertRaises(ValidationError) as wraperr:
@@ -206,25 +199,28 @@ class SchemaPermTC(MercurialServerTCMixin, CubicWebTC):
                             {'r': titi_repo.eid, 'm': self.server_config.eid})
             self.assertEqual({'hosted_by': ('Only managers or owners can set a '
                                             'repository to a mercurial-server host.')},
-                wraperr.exception.args[1])
+                             wraperr.exception.args[1])
             req = cnx.request()
             req.entity_from_eid(toto_repo.eid)
             self.assertEqual(1, len(toto_repo.reverse_granted_on))
-            content = self._hgadmin_file_content('default', self.server_config.conf_filename)
-            self.assertEqual(['write user=cw/admin/959 repo=admin_repo',
-                              'write user=cw/toto/972 repo=toto_repo'],
+            content = self._hgadmin_file_content(self.server_config.conf_filename)
+            self.assertEqual(['write user=cw/admin/%d repo=admin_repo' %
+                                self.admin_pubkey.eid,
+                              'write user=cw/toto/%d repo=toto_repo' %
+                                toto.public_key[0].eid],
                              content.splitlines())
-            pk = self._hgadmin_file_content('default', 'keys', self.server_config.keys_subdir,
-                                                toto.login, str(pubkey.eid))
+            pk = self._hgadmin_file_content('keys', self.server_config.keys_subdir,
+                                            toto.login, str(pubkey.eid))
             self.assertEqual('toto public key', pk)
         self.execute('DELETE CWUser U WHERE U login "toto"')
         self.commit()
-        content = self._hgadmin_file_content('default', self.server_config.conf_filename)
+        content = self._hgadmin_file_content(self.server_config.conf_filename)
         # all info about toto is gone
-        self.assertEqual(['write user=cw/admin/959 repo=admin_repo'],
+        self.assertEqual(['write user=cw/admin/%d repo=admin_repo' %
+                            self.admin_pubkey.eid],
                          content.splitlines())
         with self.assertRaises(IOError):
-            self._hgadmin_file_content('default', 'keys', self.server_config.keys_subdir,
+            self._hgadmin_file_content('keys', self.server_config.keys_subdir,
                                        toto.login, str(pubkey.eid))
 
 
